==> free-sa-1.3.4.tar.gz: free-sa-1.3.4/src/reports/r_userdatetime.c <==
#include "global.h"


double *ReportDateTime(FILE *ifile, double tlBytes, double (*tBytes)[12][31][24], char tlFlag) {
    short int j, year, month, day, hour;
    double dBytes, hBytes[24];
    static double mBytes[31];
    struct tm ttm;
    char dayFlag;
    
    
    SAfprintf(ifile, "<tr><th>%s<th>00:00<th>01:00<th>02:00<th>03:00<th>04:00<th>05:00<th>06:00<th>07:00<th>08:00<th>09:00<th>10:00<th>11:00<th>12:00<th>13:00<th>14:00<th>15:00<th>16:00<th>17:00<th>18:00<th>19:00<th>20:00<th>21:00<th>22:00<th>23:00<th>%s\n", loc->DsT, loc->Bytes);

    memset(hBytes, 0, 24L * sizeof(double));
    memset(mBytes, 0, 31L * sizeof(double));
    
    for (year = 0; year <= icfg.EYear - icfg.SYear; year++)
	for (month = 0; month < 12; month++)
	    for (day = 0; day < 31; day++) {
		dBytes = 0;
		dayFlag = 0;
		for (hour = 0; hour < 24; hour++) {
		    if (tBytes[year][month][day][hour]) {
			/* If just detected that day have bytes */
			if (!dayFlag) {
			    dayFlag++;
			    
			    ttm.tm_year = year + icfg.SYear;
			    ttm.tm_mon = month;
			    ttm.tm_mday = day + 1;
			    
			    SAfprintf(ifile, "<tr><th>%s", GetD(&ttm, "%x"));
			    for (j = 0; j < hour; j++) SAfwrite1("<td>0", 5L, ifile);
			}
			
			hBytes[hour] += tBytes[year][month][day][hour];
			dBytes += tBytes[year][month][day][hour];
			
			SAfprintf(ifile, "<td>%s", icfg.SAB(tBytes[year][month][day][hour]));
			if (tlFlag) tBytes[year][month][day][hour] = tBytes[year][month][day][hour] / ccueCount;
		    /* If day have bytes, but hour not */
		    } else if (dayFlag) SAfwrite1("<td>0", 5L, ifile);
		}
		
		/* If day has bytes */
		if (dayFlag) {
		    SAfprintf(ifile, "<th class=rt>%s\n", icfg.SAB(dBytes));
		    mBytes[day] += dBytes;
		}
		
	    }
    
    SAfprintf(ifile, "<tr><th>%s", loc->Bytes);
    for (j = 0; j < 24; j++) SAfprintf(ifile, "<th class=rt>%s", icfg.SAB(hBytes[j]));
    SAfprintf(ifile, "<th class=rt>%s", icfg.SAB(tlBytes));
    
    return mBytes;
}


double *ReportAnyDateTime(double (*tBytes)[12][31][24], const char *vname, const char *name, double bytes, char tlFlag) {
    FILE *UDR;
    char stext[128];
    double *retval;


    SAsnprintf(stext, sizeof(stext), "%s (%s)", loc->DsT, loc->Asc);
    UDR = SAfopenH("../", 'r', vname, stext, 1, "w", "%s/d_%s.html", icfg.ReportDir, name);
    retval = ReportDateTime(UDR, bytes, tBytes, tlFlag);
    SAfcloseH(UDR, name);
    
    return retval;
}

==> free-sa-1.4.3.tar.gz: free-sa-1.4.3/src/reports/r_userdatetime.c <==
#include "global.h"


void ReportDateTime(FILE *ifile, double tlBytes, double (*tBytes)[12][31][24]) {
    short int j, year, month, day, hour;
    double dBytes, hBytes[24];
    struct tm ttm;
    char dayFlag;
    
    
    SAfprintf(ifile, "<tr><th>%s<th>00:00<th>01:00<th>02:00<th>03:00<th>04:00<th>05:00<th>06:00<th>07:00<th>08:00<th>09:00<th>10:00<th>11:00<th>12:00<th>13:00<th>14:00<th>15:00<th>16:00<th>17:00<th>18:00<th>19:00<th>20:00<th>21:00<th>22:00<th>23:00<th>%s\n", loc->DsT, loc->Bytes);

    memset(hBytes, 0, 24L * sizeof(double));
    
    for (year = 0; year <= icfg.EYear - icfg.SYear; year++)
	for (month = 0; month < 12; month++)
	    for (day = 0; day < 31; day++) {
		dBytes = 0;
		dayFlag = 0;
		for (hour = 0; hour < 24; hour++) {
		    if (tBytes[year][month][day][hour]) {
			/* If just detected that day have bytes */
			if (!dayFlag) {
			    dayFlag++;
			    
			    ttm.tm_year = year + icfg.SYear;
			    ttm.tm_mon = month;
			    ttm.tm_mday = day + 1;
			    
			    SAfprintf(ifile, "<tr><th>%s", GetD(&ttm, "%x"));
			    for (j = 0; j < hour; j++) SAfwrite1("<td>0", 5L, ifile);
			}
			
			hBytes[hour] += tBytes[year][month][day][hour];
			dBytes += tBytes[year][month][day][hour];
			
			SAfprintf(ifile, "<td>%s", icfg.SAB(tBytes[year][month][day][hour]));
		    /* If day have bytes, but hour not */
		    } else if (dayFlag) SAfwrite1("<td>0", 5L, ifile);
		}
		
		/* If day has bytes */
		if (dayFlag) SAfprintf(ifile, "<th class=rt>%s\n", icfg.SAB(dBytes));
	    }
    
    SAfprintf(ifile, "<tr><th>%s", loc->Bytes);
    for (j = 0; j < 24; j++) SAfprintf(ifile, "<th class=rt>%s", icfg.SAB(hBytes[j]));
    SAfprintf(ifile, "<th class=rt>%s", icfg.SAB(tlBytes));
}


void ReportAnyDateTime(double (*tBytes)[12][31][24], const char *vname, const char *name, double bytes) {
    FILE *UDR;
    char stext[128];


    SAsnprintf(stext, sizeof(stext), "%s (%s)", loc->DsT, loc->Asc);
    UDR = SAfopenH("../", 'r', vname, stext, 1, "w", "%s/d_%s.html", icfg.ReportDir, name);
    ReportDateTime(UDR, bytes, tBytes);
    SAfcloseH(UDR, name);
}
